@@ -92,6 +92,11 @@ from awscli.customizations.sessionmanager import register_ssm_session
 from awscli.customizations.sms_voice import register_sms_voice_hide
 from awscli.customizations.dynamodb import register_dynamodb_paginator_fix
 from awscli.customizations.overridesslcommonname import register_override_ssl_common_name
+from awscli.customizations.kinesis import \
+    register_kinesis_list_streams_pagination_backcompat
+from awscli.customizations.quicksight import \
+    register_quicksight_asset_bundle_customizations
+from awscli.customizations.logs import register_logs_commands
 
 
 def awscli_initialize(event_handlers):
@@ -185,3 +190,6 @@ def awscli_initialize(event_handlers):
     register_sms_voice_hide(event_handlers)
     register_dynamodb_paginator_fix(event_handlers)
     register_override_ssl_common_name(event_handlers)
+    register_kinesis_list_streams_pagination_backcompat(event_handlers)
+    register_quicksight_asset_bundle_customizations(event_handlers)
+    register_logs_commands(event_handlers)
